[Bf-blender-cvs] [424c050] master: OSX: only use lionstylefullscreen when seperate spaces are used, todo: use respondsToSelector to simplify the whole detection

Jens Verwiebe noreply at git.blender.org
Tue Oct 14 12:48:24 CEST 2014


Commit: 424c050a6fc16ad077286a080d9d1134a39f7f30
Author: Jens Verwiebe
Date:   Tue Oct 14 12:48:06 2014 +0200
Branches: master
https://developer.blender.org/rB424c050a6fc16ad077286a080d9d1134a39f7f30

OSX: only use lionstylefullscreen when seperate spaces are used, todo: use respondsToSelector to simplify the whole detection

===================================================================

M	intern/ghost/intern/GHOST_WindowCocoa.mm

===================================================================

diff --git a/intern/ghost/intern/GHOST_WindowCocoa.mm b/intern/ghost/intern/GHOST_WindowCocoa.mm
index 8805dc9..af2ff58 100644
--- a/intern/ghost/intern/GHOST_WindowCocoa.mm
+++ b/intern/ghost/intern/GHOST_WindowCocoa.mm
@@ -634,12 +634,15 @@ GHOST_WindowCocoa::GHOST_WindowCocoa(
 	if (state == GHOST_kWindowStateFullScreen)
 		setState(GHOST_kWindowStateFullScreen);
 
-	//Starting with 10.9 (darwin 13.x.x), we always use Lion fullscreen, since it
-	//now has proper multi-monitor support for fullscreen
+	// Starting with 10.9 (darwin 13.x.x), we always use Lion fullscreen, since it
+	// now has better multi-monitor support for fullscreen
+    // if the screens are spawned, additional screens get useless,
+    // so we only use lionStyleFullScreen when screens have separate spaces
+    
 	char darwin_ver[10];
 	size_t len = sizeof(darwin_ver);
 	sysctlbyname("kern.osrelease", &darwin_ver, &len, NULL, 0);
-	if(darwin_ver[0] == '1' && darwin_ver[1] >= '3') {
+	if(darwin_ver[0] == '1' && darwin_ver[1] >= '3' && [NSScreen screensHaveSeparateSpaces]) {
 		m_lionStyleFullScreen = true;
 	}




More information about the Bf-blender-cvs mailing list